==> razorqt-0.5.1.tar.bz2: razorqt-0.5.1/razorqt-panel/plugin-mainmenu/translations/mainmenu_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
<context>
    <name>RazorMainMenu</name>
    <message>
        <source>Leave</source>
        <translation>выход</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <source>Razor Main Menu settings</source>
        <translation>Paзор Основные настройки меню</translation>
    </message>
    <message>
        <source>General</source>
        <translation>общий</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation>Показать текст</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation>текст кнопки</translation>
    </message>
    <message>
        <source>Menu file</source>
        <translation>меню файл</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Keyboard Shortcut</source>
        <translation>сокращенный клавиш </translation>
    </message>
    <message>
        <source>Click the button to record shortcut:</source>
        <translation>Нажмите кнопку, чтобы записать сокращенный клавиш:</translation>
    </message>
    <message>
        <source>Choose menu file</source>
        <translation>Выберите  меню Файл</translation>
    </message>
    <message>
        <source>Menu files (*.menu)</source>
        <translation>Меню файлов (*. Меню)</translation>
    </message>
</context>
</TS>

==> razorqt-0.5.2.tar.bz2: razorqt-0.5.2/razorqt-panel/plugin-mainmenu/translations/mainmenu_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
<context>
    <name>RazorMainMenu</name>
    <message>
        <source>Leave</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <source>Razor Main Menu settings</source>
        <translation>Настройки меню программ</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Основные</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation>Показывать текст</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation>Текст на кнопке</translation>
    </message>
    <message>
        <source>Menu file</source>
        <translation>Файл меню</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Keyboard Shortcut</source>
        <translation>Горячая клавиша</translation>
    </message>
    <message>
        <source>Click the button to record shortcut:</source>
        <translation>Нажмите для записи горячей клавиши:</translation>
    </message>
    <message>
        <source>Choose menu file</source>
        <translation>Укажите файл меню</translation>
    </message>
    <message>
        <source>Menu files (*.menu)</source>
        <translation>Файлы меню (*.menu)</translation>
    </message>
</context>
</TS>
